pub struct GdalLoaderInputs {
pub input: String,
pub collection: String,
pub filter: Option<String>,
pub s_srs: Option<u32>,
pub database_url: String,
}Expand description
Inputs for the gdal-loader process
Fields
input: StringInput file
collection: StringSet the collection name, defaults to layer name or osm
filter: Option<String>Filter input by layer name, imports all if not present
s_srs: Option<u32>Source srs, if omitted tries to derive from the input layer
database_url: StringPostgres database url
Implementations
Sourceimpl GdalLoaderInputs
impl GdalLoaderInputs
pub fn execute_input(&self) -> HashMap<String, Input>